@@ -110,7 +110,7 @@
 (defconst remind-keywords
   (sort
    (list "ADDOMIT" "AFTER" "AT" "BAN" "BANNER" "BEFORE" "CAL" "CLEAR"
-         "CLEAR-OMIT-CONTEXT" "COMPLETE-THROUGH" "DEBUG" "DO" "DUMP" "DUMPVARS"
+         "CLEAR-OMIT-CONTEXT" "COMPLETE-THROUGH" "COMPLETED-THROUGH" "DEBUG" "DO" "DUMP" "DUMPVARS"
          "DURATION" "ELSE" "ENDIF" "ERRMSG" "EXIT" "EXPR" "FIRST"
          "FLUSH" "FOURTH" "FRENAME" "FROM" "FSET" "FUNSET" "IF"
          "IFTRIG" "IN" "INC" "INCLUDE" "INCLUDECMD" "INFO" "LAST"
@@ -131,7 +131,7 @@
 
 (defconst remind-builtin-variables
   (sort
-   (list " $AddBlankLines" "$Ago" "$Am" "$And" "$April" "$At" "$August"
+   (list "$AddBlankLines" "$Ago" "$Am" "$And" "$April" "$At" "$August"
          "$CalcUTC" "$CalMode" "$CalType" "$Daemon" "$DateSep" "$DateTimeSep"
          "$December" "$DedupeReminders" "$DefaultColor" "$DefaultDelta"
          "$DefaultPrio" "$DefaultTDelta" "$DeltaOverride"
@@ -148,7 +148,7 @@
          "$PrefixLineNo" "$PSCal" "$RunOff" "$Saturday" "$September"
          "$SimpleCal" "$SortByDate" "$SortByPrio" "$SortByTime" "$SubsIndent"
          "$Sunday" "$SuppressImplicitWarnings" "$SuppressLRM" "$SysInclude" "$T" "$Tb" "$Td"
-         "$TerminalBackground" "$Thursday" "$TimeSep" "$TimetIs64bit" "$Tm" "$Today" "$TodoFilter"
+         "$TerminalBackground" "$TerminalHyperlinks" "$Thursday" "$TimeSep" "$TimetIs64bit" "$Tm" "$Today" "$TodoFilter"
          "$Tomorrow" "$Tt" "$Tuesday" "$Tw" "$Ty" "$U" "$Ud" "$Um"
          "$UntimedFirst" "$Use256Colors" "$UseBGVTColors" "$UseTrueColors"
          "$UseVTColors" "$Uw" "$Uy" "$WarningLevel" "$Was" "$Wednesday")
@@ -171,7 +171,7 @@
          "dusk" "easterdate" "escape" "eval" "evaltrig" "filedate" "filedatetime"
          "filedir" "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear" "hex"
          "hour" "htmlescape" "htmlstriptags" "iif" "index" "isany" "isconst" "isdst"
-         "isleap" "isomitted" "language" "localtoutc" "lower" "max"
+         "isleap" "isomitted" "ivritmon" "language" "localtoutc" "lower" "max"
          "mbasc" "mbindex" "mbstrlen" "mbsubstr" "min"
          "minsfromutc" "minute" "mon" "monnum" "moondate" "moondatetime"
          "moonphase" "moonrise" "moonrisedir" "moonset" "moonsetdir" "moontime"
