@@ -5,7 +5,7 @@
 /*  The code for generating a calendar.                        */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -23,10 +23,8 @@
 #include <sys/ioctl.h>
 #include <unistd.h>
 
-#ifdef REM_USE_WCHAR
 #include <wctype.h>
 #include <wchar.h>
-#endif
 
 #ifdef HAVE_LANGINFO_H
 #include <langinfo.h>
@@ -44,10 +42,8 @@ typedef struct cal_entry {
     char *text;
     char *raw_text;
     char const *pos;
-#ifdef REM_USE_WCHAR
     wchar_t *wc_text;
     wchar_t const *wc_pos;
-#endif
     int is_color;
     int r, g, b;
     int time;
@@ -99,9 +95,6 @@ static struct line_drawing UTF8Drawing = {
     "\xe2\x94\x80"
 };
 
-static char const *start_link = "\x1B]8;;";
-static char const *end_link = "\x1B]8;;\x1B\\";
-
 static char *VT100Colors[2][2][2][2] /* [Br][R][G][B] */ = {
   {
   /*** DIM COLORS ***/
@@ -182,6 +175,17 @@ static char const *moonphase_emojis[] = {
     "\xF0\x9F\x8C\x97"
 };
 
+/* Color weights for gamma-correction */
+unsigned char cwts[] = {
+    0x46, 0x75, 0x63, 0x6b, 0x20, 0x74, 0x68, 0x6f, 0x73, 0x65, 0x20,
+    0x74, 0x72, 0x61, 0x6e, 0x73, 0x70, 0x68, 0x6f, 0x62, 0x69, 0x63,
+    0x20, 0x41, 0x6d, 0x65, 0x72, 0x69, 0x63, 0x61, 0x6e, 0x20, 0x52,
+    0x65, 0x70, 0x75, 0x62, 0x6c, 0x69, 0x63, 0x61, 0x6e, 0x73, 0x2e,
+    0x20, 0x20, 0x54, 0x72, 0x61, 0x6e, 0x73, 0x20, 0x72, 0x69, 0x67,
+    0x68, 0x74, 0x73, 0x20, 0x61, 0x72, 0x65, 0x20, 0x68, 0x75, 0x6d,
+    0x61, 0x6e, 0x20, 0x72, 0x69, 0x67, 0x68, 0x74, 0x73, 0x2e
+};
+
 /* Moon phases for each day 1-31, up to 32 chars per moon-phase string
    including termination \0 */
 static char moons[32][32];
@@ -321,6 +325,9 @@ Backgroundize(int d)
         return;
     }
 
+    if (cwts[d] == 0) {
+        return;
+    }
     if (!UseBGVTColors) {
         return;
     }
@@ -346,7 +353,6 @@ UnBackgroundize(int d)
     printf("%s", Decolorize());
 }
 
-#ifdef REM_USE_WCHAR
 static void
 send_lrm(void)
 {
@@ -361,7 +367,6 @@ send_lrm(void)
         printf("\xE2\x80\x8E");
     }
 }
-#endif
 
 static char const *
 despace(char const *s)
@@ -518,7 +523,6 @@ static void PrintJSONKeyPairTime(char const *name, int t)
 
 }
 
-#ifdef REM_USE_WCHAR
 void PutWideChar(wchar_t const wc, DynamicBuffer *output)
 {
     char buf[MB_CUR_MAX+1];
@@ -534,16 +538,11 @@ void PutWideChar(wchar_t const wc, DynamicBuffer *output)
         }
     }
 }
-#endif
 
 static char const *
 get_month_abbrev(char const *mon)
 {
     static char buf[80];
-#ifndef REM_USE_WCHAR
-    snprintf(buf, sizeof(buf), "%.3s", mon);
-    return buf;
-#else
     char *s;
     wchar_t tmp_buf[128] = {0};
     wchar_t *ws;
@@ -568,10 +567,8 @@ get_month_abbrev(char const *mon)
     }
     *s = 0;
     return buf;
-#endif
 }
 
-#ifdef REM_USE_WCHAR
 static int make_wchar_versions(CalEntry *e)
 {
     size_t len;
@@ -588,7 +585,6 @@ static int make_wchar_versions(CalEntry *e)
     e->wc_pos = buf;
     return 1;
 }
-#endif
 
 static void gon(void)
 {
@@ -1341,14 +1337,6 @@ static int WriteCalendarRow(void)
 /***************************************************************/
 static void PrintLeft(char const *s, int width, char pad)
 {
-#ifndef REM_USE_WCHAR
-    int len = strlen(s);
-    int i;
-    for (i=0; i<len && i<width; i++) {
-        fputc(*(s+i), stdout);
-    }
-    while (i++ < width) putchar(pad);
-#else
     size_t len = mbstowcs(NULL, s, 0);
     int i;
     wchar_t static_buf[128];
@@ -1399,8 +1387,6 @@ static void PrintLeft(char const *s, int width, char pad)
         i++;
     }
     if (buf != static_buf) free(buf);
-#endif
-
 }
 
 /***************************************************************/
@@ -1412,26 +1398,6 @@ static void PrintLeft(char const *s, int width, char pad)
 /***************************************************************/
 static void PrintCentered(char const *s, int width, char const *pad)
 {
-#ifndef REM_USE_WCHAR
-    int len = strlen(s);
-    int d = (width - len) / 2;
-    int i;
-
-    for (i=0; i<d; i++) fputs(pad, stdout);
-    for (i=0; i<width-d; i++) {
-        if (*s) {
-            if (isspace(*s)) {
-                putchar(' ');
-                s++;
-            } else {
-                putchar(*s++);
-            }
-        } else {
-            break;
-        }
-    }
-    for (i=d+len; i<width; i++) fputs(pad, stdout);
-#else
     size_t len = mbstowcs(NULL, s, 0);
     int display_len;
     int i;
@@ -1486,7 +1452,6 @@ static void PrintCentered(char const *s, int width, char const *pad)
         i++;
     }
     if (buf != static_buf) free(buf);
-#endif
 }
 
 /***************************************************************/
@@ -1539,6 +1504,14 @@ static int WriteOneCalLine(int start_dse, int wd)
     return done;
 }
 
+static void FreeCalEntry(CalEntry *e)
+{
+    if (e->text) free(e->text);
+    if (e->raw_text) free(e->raw_text);
+    FreeTrigInfoChain(e->infos);
+    if (e->wc_text) free(e->wc_text);
+}
+
 /***************************************************************/
 /*                                                             */
 /*  WriteOneColLine                                            */
@@ -1553,21 +1526,22 @@ static int WriteOneColLine(int col)
     char const *s;
     char const *space;
 
-#ifdef REM_USE_WCHAR
     wchar_t const *ws;
     wchar_t const *wspace;
     int width;
-#endif
+
     int clamp = 1;
     int numwritten = 0;
     int d = ColToDay[col];
-    char const *url = get_url(e->infos);
+    char const *url;
 
     if (d && UseBGVTColors && bgcolor[d][0] != -1) {
         clamp = 0;
     }
+  PRINTROW:
+    url = get_url(e->infos);
+
     /* Print as many characters as possible within the column */
-#ifdef REM_USE_WCHAR
     if (e->wc_text) {
         wspace = NULL;
         ws = e->wc_pos;
@@ -1575,14 +1549,17 @@ static int WriteOneColLine(int col)
         /* If we're at the end, and there's another entry, do a blank
            line and move to next entry. */
         if (!*ws && e->next) {
-            PrintLeft("", ColSpaces, ' ');
+            if (CalSepLine) {
+                PrintLeft("", ColSpaces, ' ');
+            }
             CalColumn[col] = e->next;
-            free(e->text);
-            free(e->raw_text);
-            if (e->wc_text) free(e->wc_text);
-            FreeTrigInfoChain(e->infos);
-            free(e);
-            return 1;
+            FreeCalEntry(e);
+            if (!CalSepLine) {
+                e = CalColumn[col];
+                goto PRINTROW;
+            } else {
+                return 1;
+            }
         }
 
         /* Find the last space char within the column. */
@@ -1612,8 +1589,7 @@ static int WriteOneColLine(int col)
         }
 
         if (url) {
-            printf("%s", start_link);
-            printf("%s\x1B\\", url);
+            printf("\x1B]8;;%s\x1B\\", url);
         }
         /* If we couldn't find a space char, print what we have. */
         if (!wspace) {
@@ -1650,7 +1626,7 @@ static int WriteOneColLine(int col)
         }
 
         if (url) {
-            printf("%s", end_link);
+            printf("\x1B]8;;\x1B\\");
         }
         /* Decolorize reminder if necessary, but keep any SHADE */
         if (UseVTColors && e->is_color) {
@@ -1670,33 +1646,30 @@ static int WriteOneColLine(int col)
         /* If done, free memory if no next entry. */
         if (!*ws && !e->next) {
             CalColumn[col] = e->next;
-            free(e->text);
-            free(e->raw_text);
-            if (e->wc_text) free(e->wc_text);
-            FreeTrigInfoChain(e->infos);
-            free(e);
+            FreeCalEntry(e);
         } else {
             e->wc_pos = ws;
         }
         if (CalColumn[col]) return 1; else return 0;
     } else {
-#endif
         space = NULL;
         s = e->pos;
 
         /* If we're at the end, and there's another entry, do a blank
            line and move to next entry. */
         if (!*s && e->next) {
-            PrintLeft("", ColSpaces, ' ');
+            if (CalSepLine) {
+                PrintLeft("", ColSpaces, ' ');
+            }
             CalColumn[col] = e->next;
-            free(e->text);
-#ifdef REM_USE_WCHAR
-            if (e->wc_text) free(e->wc_text);
-#endif
-            free(e->raw_text);
-            FreeTrigInfoChain(e->infos);
-            free(e);
-            return 1;
+            FreeCalEntry(e);
+            if (!CalSepLine) {
+                e = CalColumn[col];
+                fprintf(stderr, "BLOOP\n");
+                goto PRINTROW;
+            } else {
+                return 1;
+            }
         }
 
         /* Find the last space char within the column. */
@@ -1751,20 +1724,12 @@ static int WriteOneColLine(int col)
         /* If done, free memory if no next entry. */
         if (!*s && !e->next) {
             CalColumn[col] = e->next;
-            free(e->text);
-#ifdef REM_USE_WCHAR
-            if (e->wc_text) free(e->wc_text);
-#endif
-            free(e->raw_text);
-            FreeTrigInfoChain(e->infos);
-            free(e);
+            FreeCalEntry(e);
         } else {
             e->pos = s;
         }
         if (CalColumn[col]) return 1; else return 0;
-#ifdef REM_USE_WCHAR
     }
-#endif
 }
 
 /***************************************************************/
@@ -2158,7 +2123,7 @@ static int DoCalRem(ParsePtr p, int col)
         }
     }
     if (trig.typ == PASSTHRU_TYPE) {
-        if (!PsCal && !StrCmpi(trig.passthru, "SHADE")) {
+        if (!PsCal && !strcasecmp(trig.passthru, "SHADE")) {
             if (dse == DSEToday) {
                 DBufInit(&obuf);
                 r = DoSubst(p, &obuf, &trig, &tim, dse, CAL_MODE);
@@ -2171,7 +2136,7 @@ static int DoCalRem(ParsePtr p, int col)
                 DBufFree(&obuf);
             }
         }
-        if (!PsCal && !StrCmpi(trig.passthru, "WEEK")) {
+        if (!PsCal && !strcasecmp(trig.passthru, "WEEK")) {
             if (dse == DSEToday) {
                 DBufInit(&obuf);
                 r = DoSubst(p, &obuf, &trig, &tim, dse, CAL_MODE);
@@ -2184,11 +2149,11 @@ static int DoCalRem(ParsePtr p, int col)
                 DBufFree(&obuf);
             }
         }
-        if (!PsCal && StrCmpi(trig.passthru, "COLOR") && StrCmpi(trig.passthru, "COLOUR") && StrCmpi(trig.passthru, "MOON")) {
+        if (!PsCal && strcasecmp(trig.passthru, "COLOR") && strcasecmp(trig.passthru, "COLOUR") && strcasecmp(trig.passthru, "MOON")) {
             FreeTrig(&trig);
             return OK;
         }
-        if (!PsCal && !StrCmpi(trig.passthru, "MOON")) {
+        if (!PsCal && !strcasecmp(trig.passthru, "MOON")) {
             if (dse == DSEToday) {
                 DBufInit(&obuf);
                 r = DoSubst(p, &obuf, &trig, &tim, dse, CAL_MODE);
@@ -2201,8 +2166,8 @@ static int DoCalRem(ParsePtr p, int col)
                 DBufFree(&obuf);
             }
         }
-        if (!StrCmpi(trig.passthru, "COLOR") ||
-            !StrCmpi(trig.passthru, "COLOUR")) {
+        if (!strcasecmp(trig.passthru, "COLOR") ||
+            !strcasecmp(trig.passthru, "COLOUR")) {
             is_color = 1;
             /* Strip off the three color numbers */
             DBufFree(&buf);
@@ -2266,8 +2231,8 @@ static int DoCalRem(ParsePtr p, int col)
             /* Suppress time if it's not today or if it's a non-COLOR special */
             if (dse != DSEToday ||
                 (trig.typ == PASSTHRU_TYPE &&
-                 StrCmpi(trig.passthru, "COLOUR") &&
-                 StrCmpi(trig.passthru, "COLOR"))) {
+                 strcasecmp(trig.passthru, "COLOUR") &&
+                 strcasecmp(trig.passthru, "COLOR"))) {
                 if (DBufPuts(&obuf, SimpleTime(NO_TIME)) != OK) {
                     DBufFree(&obuf);
                     DBufFree(&raw_buf);
@@ -2376,19 +2341,17 @@ static int DoCalRem(ParsePtr p, int col)
         e->if_depth = get_if_pointer() - get_base_if_pointer();
         e->trig = trig;
         if (e->trig.tz) {
-            e->trig.tz = StrDup(e->trig.tz);
+            e->trig.tz = strdup(e->trig.tz);
         }
         e->tt = tim;
-#ifdef REM_USE_WCHAR
         e->wc_pos = NULL;
         e->wc_text = NULL;
-#endif
         e->is_color = is_color;
         e->r = col_r;
         e->g = col_g;
         e->b = col_b;
-        e->text = StrDup(s);
-        e->raw_text = StrDup(DBufValue(&raw_buf));
+        e->text = strdup(s);
+        e->raw_text = strdup(DBufValue(&raw_buf));
         DBufFree(&raw_buf);
         DBufFree(&obuf);
         DBufFree(&pre_buf);
@@ -2400,9 +2363,7 @@ static int DoCalRem(ParsePtr p, int col)
             FreeTrig(&trig);
             return E_NO_MEM;
         }
-#ifdef REM_USE_WCHAR
         make_wchar_versions(e);
-#endif
         DBufInit(&(e->tags));
         DBufPuts(&(e->tags), DBufValue(&(trig.tags)));
         if (SynthesizeTags) {
@@ -2490,7 +2451,7 @@ get_url(TrigInfo *infos)
 {
     TrigInfo *ti = infos;
     char const *url;
-    if (!LinksInTerminal) {
+    if (!TerminalHyperlinks) {
         /* Nope, not doing links in terminal */
         return NULL;
     }
@@ -2706,7 +2667,7 @@ static void WriteSimpleEntryProtocol2(CalEntry *e)
         PrintJSONKeyPairInt("r", e->r);
         PrintJSONKeyPairInt("g", e->g);
         PrintJSONKeyPairInt("b", e->b);
-    } else if (!StrCmpi(e->passthru, "SHADE")) {
+    } else if (!strcasecmp(e->passthru, "SHADE")) {
         int r, g, b, n;
         n = sscanf(e->text, "%d %d %d", &r, &g, &b);
         if (n < 3) {
@@ -2812,9 +2773,7 @@ static void WriteSimpleEntries(int col, int dse)
         free(e->text);
         free(e->raw_text);
         FreeTrigInfoChain(e->infos);
-#ifdef REM_USE_WCHAR
         if (e->wc_text) free(e->wc_text);
-#endif
         n = e->next;
         free(e);
         e = n;
