@@ -7,7 +7,7 @@
 /*  commands.                                                  */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -306,11 +306,11 @@ ensure_satnode_mentions_trigdate_aux(expr_node *node, int *mentioned)
         } else {
             name = node->u.value.v.str;
         }
-        if (!StrCmpi(name, "T") ||
-            !StrCmpi(name, "Td") ||
-            !StrCmpi(name, "Tm") ||
-            !StrCmpi(name, "Tw") ||
-            !StrCmpi(name, "Ty")) {
+        if (!strcasecmp(name, "T") ||
+            !strcasecmp(name, "Td") ||
+            !strcasecmp(name, "Tm") ||
+            !strcasecmp(name, "Tw") ||
+            !strcasecmp(name, "Ty")) {
             *mentioned = 1;
             return;
         }
@@ -1120,7 +1120,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
             if (r != OK) {
                 return r;
             }
-            trig->tz = StrDup(DBufValue(&buf));
+            trig->tz = strdup(DBufValue(&buf));
             if (!trig->tz) {
                 return E_NO_MEM;
             }
@@ -1555,6 +1555,7 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is
     DynamicBuffer pre_buf;
     char const *s;
     char const *msg_command = NULL;
+    char const *url;
     Value v;
 
     if (MsgCommand) {
@@ -1576,14 +1577,14 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is
     DBufInit(&calRow);
     DBufInit(&pre_buf);
     if (t->typ == RUN_TYPE && RunDisabled) return E_RUN_DISABLED;
-    if ((t->typ == PASSTHRU_TYPE && StrCmpi(t->passthru, "COLOR") && StrCmpi(t->passthru, "COLOUR")) ||
+    if ((t->typ == PASSTHRU_TYPE && strcasecmp(t->passthru, "COLOR") && strcasecmp(t->passthru, "COLOUR")) ||
         t->typ == CAL_TYPE ||
         t->typ == PS_TYPE ||
         t->typ == PSF_TYPE)
         return OK;
 
     /* Handle COLOR types */
-    if (t->typ == PASSTHRU_TYPE && (!StrCmpi(t->passthru, "COLOR") || !StrCmpi(t->passthru, "COLOUR"))) {
+    if (t->typ == PASSTHRU_TYPE && (!strcasecmp(t->passthru, "COLOR") || !strcasecmp(t->passthru, "COLOUR"))) {
         /* Strip off three tokens */
         r = ParseToken(p, &buf);
         sscanf(DBufValue(&buf), "%d", &red);
@@ -1830,9 +1831,16 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is
         }
     }
 
-/* If we are sorting, just queue it up in the sort buffer */
+    /* Get the url if terminal hyperlinks are enabled */
+    if (TerminalHyperlinks) {
+        url = FindTrigInfo(t, "url");
+    } else {
+        url = NULL;
+    }
+
+    /* If we are sorting, just queue it up in the sort buffer */
     if (SortByDate) {
-        if (InsertIntoSortBuffer(dse, tim->ttime, DBufValue(&buf),
+        if (InsertIntoSortBuffer(dse, tim->ttime, url, DBufValue(&buf),
                                  t->typ, t->priority) == OK) {
             DBufFree(&buf);
             NumTriggered++;
@@ -1855,14 +1863,20 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is
                 if (IsServerMode() && !strncmp(DBufValue(&buf), "NOTE endreminder", 16)) {
                     printf(" %s", DBufValue(&buf));
                 } else {
+                    if (url) {
+                        printf("\x1B]8;;%s\x1B\\", url);
+                    }
                     printf("%s", DBufValue(&buf));
+                    if (url) {
+                        printf("\x1B]8;;\x1B\\");
+                    }
                 }
             }
         }
         break;
 
     case MSF_TYPE:
-        FillParagraph(DBufValue(&buf), output);
+        FillParagraph(url, DBufValue(&buf), output);
         break;
 
     case RUN_TYPE:
@@ -2269,7 +2283,9 @@ static int ShouldTriggerBasedOnWarn(Trigger const *t, int dse, int *err)
             while(iter++ <= max) {
                 j--;
                 *err = IsOmitted(j, t->localomit, t->omitfunc, &omit);
-                if (*err) return 0;
+                if (*err) {
+                    return (dse == DSEToday);
+                }
                 if (!omit) v.v.val++;
                 if (!v.v.val) {
                     break;
@@ -2277,7 +2293,7 @@ static int ShouldTriggerBasedOnWarn(Trigger const *t, int dse, int *err)
             }
             if (iter > max) {
                 Eprint("Delta: Bad OMITFUNC? %s", GetErr(E_CANT_TRIG));
-                return 0;
+                return (dse == DSEToday);
             }
             if (j == DSEToday) return 1;
         }
@@ -2291,17 +2307,17 @@ void FixSpecialType(Trigger *t)
     }
 
     /* Convert SPECIAL MSG / MSF / RUN / CAL to just plain MSG / MSF / etc */
-    if (!StrCmpi(t->passthru, "MSG")) {
+    if (!strcasecmp(t->passthru, "MSG")) {
         t->typ = MSG_TYPE;
-    } else if (!StrCmpi(t->passthru, "MSF")) {
+    } else if (!strcasecmp(t->passthru, "MSF")) {
         t->typ = MSF_TYPE;
-    } else if (!StrCmpi(t->passthru, "RUN")) {
+    } else if (!strcasecmp(t->passthru, "RUN")) {
         t->typ = RUN_TYPE;
-    } else if (!StrCmpi(t->passthru, "CAL")) {
+    } else if (!strcasecmp(t->passthru, "CAL")) {
         t->typ = CAL_TYPE;
-    } else if (!StrCmpi(t->passthru, "PS")) {
+    } else if (!strcasecmp(t->passthru, "PS")) {
         t->typ = PS_TYPE;
-    } else if (!StrCmpi(t->passthru, "PSFILE")) {
+    } else if (!strcasecmp(t->passthru, "PSFILE")) {
         t->typ = PSF_TYPE;
     }
 }
