@@ -6,7 +6,7 @@
 /*  buffers.                                                   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -17,6 +17,15 @@
 #include <string.h>
 #include <stdlib.h>
 
+static size_t NumMallocs = 0;
+static size_t BytesMalloced = 0;
+
+void DBufGetMallocStats(size_t *num_mallocs, size_t *bytes_malloced)
+{
+    *num_mallocs = NumMallocs;
+    *bytes_malloced = BytesMalloced;
+}
+
 /**********************************************************************
 %FUNCTION: DBufMakeRoom
 %ARGUMENTS:
@@ -45,6 +54,9 @@ static int DBufMakeRoom(DynamicBuffer *dbuf, size_t n)
     buf = malloc(size);
     if (!buf) return E_NO_MEM;
 
+    NumMallocs++;
+    BytesMalloced += size;
+
     /* Copy contents */
     strcpy(buf, dbuf->buffer);
 
