@@ -5,7 +5,7 @@
 /*  Error definitions.                                         */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -134,11 +134,10 @@
 #define E_MAX_OVERDUE_WITHOUT_TODO 110
 #define E_TZ_SPECIFIED_TWICE 111
 #define E_TZ_NO_AT          112
-#define E_NO_MB             113
-#define E_BAD_MB_SEQ        114
-#define E_EXPR_NODES_EXCEEDED 115
-#define E_EXPECTING_EOXPR   116
-#define E_EXPECTING_ATOM    117
+#define E_BAD_MB_SEQ        113
+#define E_EXPR_NODES_EXCEEDED 114
+#define E_EXPECTING_EOXPR   115
+#define E_EXPECTING_ATOM    116
 
 #ifdef MK_GLOBALS
 #undef EXTERN
@@ -152,7 +151,6 @@
 #define STR2(X) #X
 
 
-#ifndef L_ERR_OVERRIDE
 EXTERN char *ErrMsg[]
 
 #ifdef MK_GLOBALS
@@ -270,7 +268,6 @@ EXTERN char *ErrMsg[]
 /* E_MAX_OVERDUE_WITHOUT_TODO */ "MAX-OVERDUE specified without TODO",
 /* E_TZ_SPECIFIED_TWICE */ "TZ specified twice",
 /* E_TZ_NO_AT */           "TZ specified for non-timed reminder",
-/* E_NO_MB */              "C library does not support multibyte characters",
 /* E_BAD_MB_SEQ */         "Invalid multibyte sequence",
 /* E_EXPR_NODES_EXCEEDED */ "Maximum expression complexity exceeded",
 /* E_EXPECTING_EOXPR */    "Expecting operator or end-of-expression",
@@ -278,7 +275,6 @@ EXTERN char *ErrMsg[]
 }
 #endif /* MK_GLOBALS */
 ;
-#endif /* L_ERR_OVERRIDE */
 
 EXTERN int NumErrs
 #ifdef MK_GLOBALS
