@@ -7,7 +7,7 @@
 /*  MK_GLOBALS.  Also contains useful macro definitions.       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -106,7 +106,6 @@ EXTERN  INIT(   int     DefaultPrio, NO_PRIORITY);
 EXTERN  INIT(   int     SysTime, -1);
 EXTERN  INIT(   int     LocalSysTime, -1);
 EXTERN  INIT(   int     ParseUntriggered, 0);
-EXTERN  INIT(   int     LinksInTerminal, 0);
 
 EXTERN  char    const *InitialFile;
 EXTERN  char    const *LocalTimeZone;
@@ -147,6 +146,7 @@ EXTERN  int ArgC;
 EXTERN  char const **ArgV;
 EXTERN  INIT(   int     CalLines, CAL_LINES);
 EXTERN  INIT(   int     CalPad, 1);
+EXTERN  INIT(   int     CalSepLine, 1);
 EXTERN  INIT(   int     UseVTChars, 0);
 EXTERN  INIT(   int     UseBGVTColors, 0);
 EXTERN  INIT(   int     UseUTF8Chars, 0);
@@ -171,6 +171,10 @@ EXTERN  INIT(   double    Latitude, DEFAULT_LATITUDE);
 
 EXTERN  INIT(   char      *Location, LOCATION);
 
+/* Support hyperlinks in terminal emulators?
+   https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda
+*/
+EXTERN  INIT(   int       TerminalHyperlinks, 0);
 /* UTC calculation stuff */
 EXTERN  INIT(   int       MinsFromUTC, 0);
 EXTERN  INIT(   int       CalculateUTC, 1);
