@@ -5,7 +5,7 @@
 /*  Support for the Hebrew calendar                            */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /*  Derived from code written by Amos Shapir in 1978; revised  */
@@ -61,10 +61,58 @@
 #define ADAR2ADARA 1
 #define ADAR2BOTH  2
 
+struct AltMonthName {
+    char const *name;
+    int mon;
+};
+
 static char const *HebMonthNames[] = {
     "Tishrey", "Heshvan", "Kislev", "Tevet", "Shvat", "Adar A", "Adar B",
     "Nisan", "Iyar", "Sivan", "Tamuz", "Av", "Elul", "Adar"};
 
+static char const *IvritMonthNames[] = {
+"תשרי",
+"חשוון",
+"כסלו",
+"טבת",
+"שבט",
+"אדר א'",
+"אדר ב'",
+"ניסן",
+"אייר",
+"סיון",
+"תמוז",
+"אב",
+"אלול",
+"אדר" };
+
+/* Alternate spellings */
+static struct AltMonthName AltMonthSpellings[] = {
+    { "Tishri",   TISHREY },
+    { "Tishrei",  TISHREY },
+
+    { "Cheshvan", HESHVAN },
+    { "Kheshvan", HESHVAN },
+
+    { "Shevat",   SHVAT   },
+
+    { "Tammuz",   TAMUZ   },
+
+    { "Adar 1",   ADARA   },
+    { "Adar I",   ADARA   },
+    { "אדר א",    ADARA   },
+    { "אדר 1",    ADARA   },
+    { "אדר I",    ADARA   },
+
+    { "Adar 2",   ADARB   },
+    { "Adar II",  ADARB   },
+    { "אדר ב",    ADARB   },
+    { "אדר 2",    ADARB   },
+    { "אדר II",   ADARB   },
+
+    { "Iyyar",    IYAR    }
+};
+
 static char MaxMonLen[] = {
     30, 30, 30, 29, 30, 30, 29, 30, 29, 30, 29, 30, 29, 29};
 
@@ -245,14 +293,32 @@ int HebNameToNum(char const *mname)
     int i;
     int m=-1;
 
-    for (i=0; i<14; i++)
-        if (!StrCmpi(mname, HebMonthNames[i])) {
+    for (i=0; i<14; i++) {
+        if (!strcasecmp(mname, HebMonthNames[i])) {
             m = i;
             break;
         }
+    }
+    if (m == -1) {
+        for (i=0; i<14; i++) {
+            if (!strcmp(mname, IvritMonthNames[i])) {
+                m = i;
+                break;
+            }
+        }
+    }
 
+    /* Try the alternate spellings */
+    if (m == -1) {
+        for (i=0; i < (int) (sizeof(AltMonthSpellings) / sizeof(AltMonthSpellings[0])); i++) {
+            if (!strcasecmp(mname, AltMonthSpellings[i].name)) {
+                m = AltMonthSpellings[i].mon;
+                break;
+            }
+        }
+    }
     return m;
-}   
+}
 
 /***************************************************************/
 /*                                                             */
@@ -270,6 +336,22 @@ char const *HebMonthName(int m, int y)
     else return HebMonthNames[m];
 }
 
+/***************************************************************/
+/*                                                             */
+/*  IvritMonthname                                             */
+/*                                                             */
+/*  Convert a Hebrew month's number to its name in Hebrew      */
+/*  script, given the year.                                    */
+/*                                                             */
+/***************************************************************/
+char const *IvritMonthName(int m, int y)
+{
+    if (m != ADARA && m != ADARB) return IvritMonthNames[m];
+
+    if (!HebIsLeap[(y-1)%19]) return IvritMonthNames[ADAR];
+    else return IvritMonthNames[m];
+}
+
 /***************************************************************/
 /*                                                             */
 /* GetValidHebDate                                             */
