@@ -7,7 +7,7 @@
 /*  in normal mode.                                            */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -196,7 +196,7 @@ void InitRemind(int argc, char const *argv[])
     /* Initialize local time zone */
     LocalTimeZone = getenv("TZ");
     if (LocalTimeZone) {
-        LocalTimeZone = StrDup(LocalTimeZone);
+        LocalTimeZone = strdup(LocalTimeZone);
         if (!LocalTimeZone) {
             fprintf(stderr, "Out of memory!\n");
             exit(1);
@@ -514,13 +514,13 @@ void InitRemind(int argc, char const *argv[])
                         arg++;
                         continue;
                     }
-                    if (*arg == 'c' || *arg == 'C') {
-                        UseVTColors = 1;
+                    if (*arg == 'z' || *arg == 'Z') {
+                        TerminalHyperlinks = 1;
                         arg++;
                         continue;
                     }
-                    if (*arg == 'z' || *arg == 'Z') {
-                        LinksInTerminal = 1;
+                    if (*arg == 'c' || *arg == 'C') {
+                        UseVTColors = 1;
                         arg++;
                         continue;
                     }
@@ -649,8 +649,17 @@ void InitRemind(int argc, char const *argv[])
                     }
                     if (*arg == ',') {
                         arg++;
-                        PARSENUM(CalPad, arg);
-                        if (CalPad > 20) CalPad = 20;
+                        if (*arg != ',') {
+                            PARSENUM(CalPad, arg);
+                            if (CalPad > 20) CalPad = 20;
+                        }
+                        if (*arg == ',') {
+                            arg++;
+                            PARSENUM(CalSepLine, arg);
+                            if (CalSepLine) {
+                                CalSepLine = 1;
+                            }
+                        }
                     }
                 }
                 break;
@@ -852,7 +861,7 @@ void InitRemind(int argc, char const *argv[])
 #ifndef L_USAGE_OVERRIDE
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s Copyright (C) 1992-2025 Dianne Skoll\n", VERSION);
+    fprintf(ErrFp, "\nREMIND %s Copyright (C) 1992-2026 Dianne Skoll\n", VERSION);
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
 #endif
