@@ -6,7 +6,7 @@
 /*  routines, etc.                                             */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -39,10 +39,8 @@
 #include <time.h>
 
 #include <sys/types.h>
-#ifdef REM_USE_WCHAR
 #include <wctype.h>
 #include <wchar.h>
-#endif
 
 #include "types.h"
 #include "protos.h"
@@ -64,12 +62,17 @@ exitfunc(void)
     /* Kill any execution-time-limiter process */
     unlimit_execution_time();
 
+    size_t num_mallocs, bytes_malloced;
+
     if (DebugFlag & DB_UNUSED_VARS) {
         DumpUnusedVars();
     }
     if (DebugFlag & DB_HASHSTATS) {
         fflush(stdout);
         fflush(ErrFp);
+        DBufGetMallocStats(&num_mallocs, &bytes_malloced);
+        fprintf(ErrFp, "DynBuf Mallocs: %lu mallocs; %lu bytes\n",
+                (unsigned long) num_mallocs, (unsigned long) bytes_malloced);
         fprintf(ErrFp, "Variable hash table statistics:\n");
         dump_var_hash_stats();
 
@@ -1518,11 +1521,11 @@ int DoRun(ParsePtr p)
     if ( (r=ParseToken(p, &buf)) ) return r;
 
 /* Only allow RUN ON in top-level script */
-    if (! StrCmpi(DBufValue(&buf), "ON")) {
+    if (! strcasecmp(DBufValue(&buf), "ON")) {
         if (TopLevel()) RunDisabled &= ~RUN_SCRIPT;
     }
 /* But allow RUN OFF anywhere */
-    else if (! StrCmpi(DBufValue(&buf), "OFF"))
+    else if (! strcasecmp(DBufValue(&buf), "OFF"))
         RunDisabled |= RUN_SCRIPT;
     else {
         DBufFree(&buf);
@@ -1550,11 +1553,11 @@ int DoExpr(ParsePtr p)
     if ( (r=ParseToken(p, &buf)) ) return r;
 
 /* Only allow EXPR ON in top-level script */
-    if (! StrCmpi(DBufValue(&buf), "ON")) {
+    if (! strcasecmp(DBufValue(&buf), "ON")) {
         if (TopLevel()) ExpressionEvaluationDisabled = 0;
     }
 /* But allow EXPR OFF anywhere */
-    else if (! StrCmpi(DBufValue(&buf), "OFF"))
+    else if (! strcasecmp(DBufValue(&buf), "OFF"))
         ExpressionEvaluationDisabled = 1;
     else {
         DBufFree(&buf);
@@ -1730,7 +1733,6 @@ static char const *OutputEscapeSequences(char const *s, int print, DynamicBuffer
     return s;
 }
 
-#ifdef REM_USE_WCHAR
 #define ISWBLANK(c) (iswspace(c) && (c) != '\n')
 static wchar_t const *OutputEscapeSequencesWS(wchar_t const *s, int print, DynamicBuffer *output)
 {
@@ -1848,7 +1850,7 @@ FillParagraphWC(char const *s, DynamicBuffer *output)
     free(buf);
     return OK;
 }
-#endif
+
 /***************************************************************/
 /*                                                             */
 /*  FillParagraph                                              */
@@ -1864,7 +1866,7 @@ FillParagraphWC(char const *s, DynamicBuffer *output)
 /* A macro safe ONLY if used with arg with no side effects! */
 #define ISBLANK(c) (isspace(c) && (c) != '\n')
 
-void FillParagraph(char const *s, DynamicBuffer *output)
+void FillParagraph(char const *url, char const *s, DynamicBuffer *output)
 {
 
     int line = 0;
@@ -1881,11 +1883,16 @@ void FillParagraph(char const *s, DynamicBuffer *output)
     while(ISBLANK(*s)) s++;
     if (!*s) return;
 
-#ifdef REM_USE_WCHAR
+    if (url) {
+        printf("\x1B]8;;%s\x1B\\", url);
+    }
+
     if (FillParagraphWC(s, output) == OK) {
+        if (url) {
+            printf("\x1B]8;;\x1B\\");
+        }
         return;
     }
-#endif
 
     /* Start formatting */
     while(1) {
@@ -1899,6 +1906,9 @@ void FillParagraph(char const *s, DynamicBuffer *output)
             continue;
         }
         if (!*s) {
+            if (url) {
+                printf("\x1B]8;;\x1B\\");
+            }
             return;
         }
         /* Over here, we're at the beginning of a line.  Emit the correct
@@ -1933,6 +1943,9 @@ void FillParagraph(char const *s, DynamicBuffer *output)
                 len++;
             }
             if (s == t) {
+                if (url) {
+                    printf("\x1B]8;;\x1B\\");
+                }
                 return;
             }
             if (!pendspace || len+pendspace <= roomleft) {
@@ -2122,7 +2135,7 @@ SaveLastTrigger(Trigger const *t)
     DBufInit(&(LastTrigger.tags));
 
     if (LastTrigger.tz) {
-        LastTrigger.tz = StrDup(LastTrigger.tz);
+        LastTrigger.tz = strdup(LastTrigger.tz);
     }
     DBufPuts(&(LastTrigger.tags), DBufValue(&(t->tags)));
     TrigInfo *cur = t->infos;
