@@ -6,7 +6,7 @@
 /*  the TRANSLATE keyword.                                     */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -443,19 +443,19 @@ DoTranslate(ParsePtr p)
         r = ParseToken(p, &orig);
         if (r) return r;
         r = VerifyEoln(p);
-        if (!StrCmpi(DBufValue(&orig), "dump")) {
+        if (!strcasecmp(DBufValue(&orig), "dump")) {
             DBufFree(&orig);
             if (r) return r;
             DumpTranslationTable(stdout, 0);
             return OK;
         }
-        if (!StrCmpi(DBufValue(&orig), "clear")) {
+        if (!strcasecmp(DBufValue(&orig), "clear")) {
             DBufFree(&orig);
             if (r) return r;
             ClearTranslationTable();
             return OK;
         }
-        if (!StrCmpi(DBufValue(&orig), "generate")) {
+        if (!strcasecmp(DBufValue(&orig), "generate")) {
             DBufFree(&orig);
             if (r) return r;
             GenerateTranslationTemplate();
