@@ -5,7 +5,7 @@
 /*  Routines for figuring out the trigger date of a reminder   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -738,7 +738,7 @@ NewTrigInfo(char const *i)
         return NULL;
     }
     ti->next = NULL;
-    ti->info = StrDup(i);
+    ti->info = strdup(i);
     if (!ti->info) {
         free(ti);
         return NULL;
