@@ -6,7 +6,7 @@
 /*  user- and system-defined variables.                        */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -52,7 +52,7 @@ static int VarCompareFunc(void const *a, void const *b)
 {
     Var *x = (Var *) a;
     Var *y = (Var *) b;
-    return StrCmpi(x->name, y->name);
+    return strcasecmp(x->name, y->name);
 }
 
 void
@@ -220,15 +220,15 @@ static int warning_level_func(int do_set, Value *val)
         if (!strcmp(val->v.str, VERSION)) {
             WarningLevel = NULL;
         } else {
-            WarningLevel = StrDup(val->v.str);
+            WarningLevel = strdup(val->v.str);
             if (!WarningLevel) return E_NO_MEM;
         }
         return OK;
     }
     if (!WarningLevel) {
-        val->v.str = StrDup(VERSION);
+        val->v.str = strdup(VERSION);
     } else {
-        val->v.str = StrDup(WarningLevel);
+        val->v.str = strdup(WarningLevel);
     }
     if (!val->v.str) {
         return E_NO_MEM;
@@ -257,14 +257,14 @@ static int oncefile_func(int do_set, Value *val)
         if (OnceFile) {
             free( (void *) OnceFile);
         }
-        OnceFile = StrDup(val->v.str);
+        OnceFile = strdup(val->v.str);
         if (!OnceFile) return E_NO_MEM;
         return OK;
     }
     if (!OnceFile) {
-        val->v.str = StrDup("");
+        val->v.str = strdup("");
     } else {
-        val->v.str = StrDup(OnceFile);
+        val->v.str = strdup(OnceFile);
     }
     if (!val->v.str) return E_NO_MEM;
     val->type = STR_TYPE;
@@ -403,6 +403,14 @@ static int trig_wday_func(int do_set, Value *val)
     return OK;
 }
 
+/* Cache $Ud, $Um and $Uy */
+static int Ucached = -1;
+static int Udcached = -1;
+static int Umcached = -1;
+static int Uycached = -1;
+
+#define FILL_U_CACHE(x) do { if (Ucached != x) { FromDSE(x, &Uycached, &Umcached, &Udcached); Ucached = x; } } while(0)
+
 static int today_date_func(int do_set, Value *val)
 {
     UNUSED(do_set);
@@ -412,31 +420,28 @@ static int today_date_func(int do_set, Value *val)
 }
 static int today_day_func(int do_set, Value *val)
 {
-    int d;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, NULL, NULL, &d);
-    val->v.val = d;
+    FILL_U_CACHE(DSEToday);
+    val->v.val = Udcached;
     return OK;
 }
 
 static int today_mon_func(int do_set, Value *val)
 {
-    int m;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, NULL, &m, NULL);
-    val->v.val = m+1;
+    FILL_U_CACHE(DSEToday);
+    val->v.val = Umcached + 1;
     return OK;
 }
 
 static int today_year_func(int do_set, Value *val)
 {
-    int y;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, &y, NULL, NULL);
-    val->v.val = y;
+    FILL_U_CACHE(DSEToday);
+    val->v.val = Uycached;
     return OK;
 }
 
@@ -1109,6 +1114,7 @@ static SysVar SysVarArr[] = {
     {"Tb",             0,  SPECIAL_TYPE, trig_base_func,       0,      0 },
     {"Td",             0,  SPECIAL_TYPE, trig_day_func,        0,      0 },
     {"TerminalBackground", 0, SPECIAL_TYPE,  terminal_bg_func, 0,      0 },
+    {"TerminalHyperlinks", 1, INT_TYPE,  &TerminalHyperlinks,  0,      1 },
     {"Thursday",       1,  TRANS_TYPE,   "Thursday",           0,      0 },
     {"TimeSep",        1,  SPECIAL_TYPE, time_sep_func,        0,      0 },
     {"TimetIs64bit",   0,  SPECIAL_TYPE, timet_is_64_func,     0,      0 },
@@ -1397,9 +1403,9 @@ static int GetTranslatableVariable(SysVar const *v, Value *value)
 {
     char const *translated = tr((char const *) v->value);
     if (translated) {
-        value->v.str = StrDup(translated);
+        value->v.str = strdup(translated);
     } else {
-        value->v.str = StrDup("");
+        value->v.str = strdup("");
     }
     if (!value->v.str) return E_NO_MEM;
     value->type = STR_TYPE;
@@ -1491,9 +1497,9 @@ int GetSysVar(char const *name, Value *val)
         return f(0, val);
     } else if (v->type == STR_TYPE) {
         if (! * (char **) v->value) {
-            val->v.str = StrDup("");
+            val->v.str = strdup("");
         } else {
-            val->v.str = StrDup(*((char **) v->value));
+            val->v.str = strdup(*((char **) v->value));
         }
         if (!val->v.str) return E_NO_MEM;
     } else {
@@ -1524,7 +1530,7 @@ SysVar *FindSysVar(char const *name)
     int r;
 
     while (top >= bottom) {
-        r = StrCmpi(name, SysVarArr[mid].name);
+        r = strcasecmp(name, SysVarArr[mid].name);
         if (!r) return &SysVarArr[mid];
         else if (r>0) bottom = mid+1;
         else        top = mid-1;
